/*

Copyright (C) NEC Corporation 2012. All Rights Reserved.
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

*/

package com.necsoft.hinemos.webclient.jobmanagement.servlet;

import java.io.IOException;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
import com.necsoft.hinemos.webclient.bean.Property;
import com.necsoft.hinemos.webclient.common.Constants;
import com.necsoft.hinemos.webclient.common.DataProcess;
import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
import com.necsoft.hinemos.webclient.exception.HinemosWebException;
import com.necsoft.hinemos.webclient.exception.HinemosWebRemoteException;
import com.necsoft.hinemos.webclient.jobmanagement.business.GetHistoryBusiness;
import com.necsoft.hinemos.webclient.jobmanagement.form.HistoryForm;
import com.necsoft.hinemos.webclient.json.CommonJson;
import com.necsoft.hinemos.webclient.servlet.CommonServlet;
import com.necsoft.hinemos.webclient.util.ExceptionHandlerUtils;
import com.necsoft.hinemos.webclient.util.LogUtils;
import com.necsoft.hinemos.webclient.util.LoginManager;
import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;

/**
 * This class used for get History info
 *
 * @version 1.0.0
 * @since 1.0.0
 **/
public class GetHistoryServlet extends CommonServlet {
    private static final long serialVersionUID = -7775038566425028930L;

    private static LogUtils logUtils = LogUtils
            .getLogUtils(GetHistoryServlet.class);

    /**
     * Get History info
     *
     * @param request
     *            : HttpServletRequest
     * @param response
     *            : HttpServletResponse
     * @throws ServletException
     * @throws IOException
     * @throws HinemosWebAccessException
     */
    @Override
    public CommonJson process(HttpServletRequest request,
            HttpServletResponse response) throws ServletException, IOException,
            HinemosWebAccessException {

        // 中間変数を宣言
        CommonJson result = new CommonJson();

        try {
            // Get Data
            List<ArrayList<Object>> listInfoData = doLoadListInfoData(request);

            // Convert data to JSON structure
            result = DataProcess.doConvertTableContentToJson(listInfoData);

        } catch (HinemosWebAccessException ex) {
            logUtils.info(ex.getMessage());
            throw new HinemosWebAccessException();
        } catch (HinemosWebRemoteException ex) {
            logUtils.error(ex.getMessage(), ex.getCause());
            result = ExceptionHandlerUtils.doBuildCommonJson(
                    ExceptionHandlerUtils.LEVEL_WARNING, ex.getMessage(), request.getLocale());

        } catch (Exception ex) {
            logUtils.error(ex.getMessage(), ex.getCause());
            result = ExceptionHandlerUtils.doBuildCommonJson(
                    ExceptionHandlerUtils.LEVEL_ERROR, ex.getMessage(), request.getLocale());
        }
        return result;
    }

    /**
     * ジョブ[履歴]情報一覧データを取得
     */
    private List<ArrayList<Object>> doLoadListInfoData(HttpServletRequest request)
        throws HinemosWebException {

        // 中間変数を宣言
        HistoryForm form = new HistoryForm();
        List<ArrayList<Object>> list = null;

        PopulateBeanUtils.populateBean(form, request);

        //Get loginManager session
        HttpSession session = request.getSession(true);

        int maxRowNum = (Integer)request.getSession().getServletContext().getAttribute(Constants.JOB_HISTORY_MAX_ROW);
        synchronized(session) {
            @SuppressWarnings("unchecked")
            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);

            form.setMaxRowNum(maxRowNum);
            //Check filter
            if (form.isFilter()) {
                list = processFitler(request, form, loginManagerMap);
            } else {
                list = processNoneFilter(request, form, loginManagerMap);
            }
        }
        return list;
    }

    private List<ArrayList<Object>> processFitler(HttpServletRequest request,
            HistoryForm form, LinkedHashMap<String, LoginManager> loginManagerMap)
            throws HinemosWebException {
        Property condition = doLoadCondition(request);
        GetHistoryBusiness business = new GetHistoryBusiness();
        return business.getHistory(form, condition, loginManagerMap, request.getLocale());
    }

    private List<ArrayList<Object>> processNoneFilter(HttpServletRequest request,
            HistoryForm form, LinkedHashMap<String, LoginManager> loginManagerMap) throws HinemosWebException {
        GetHistoryBusiness business = new GetHistoryBusiness();
        return business.getHistory(form, null, loginManagerMap, request.getLocale());
    }

    private Property doLoadCondition(HttpServletRequest request)
            throws HinemosWebException {

        HttpSession session = request.getSession(true);
        if (session.getAttribute(Constants.HISTORY_FILTER_PROPERTIES) == null) {
            // HTTPセッションのタイムアウトが発生しました。ログアウトします。
            throw new HinemosWebException("message.sessiontimeout");
        }

        Property condition = (Property) session.getAttribute(Constants.HISTORY_FILTER_PROPERTIES);
        convertCondition(request, condition);

        return condition;
    }
}