/*

Copyright (C) NEC Corporation 2012. All Rights Reserved.
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

*/

package com.necsoft.hinemos.webclient.jobmanagement.servlet;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedHashMap;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
import com.necsoft.hinemos.webclient.common.DataProcess;
import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
import com.necsoft.hinemos.webclient.exception.HinemosWebException;
import com.necsoft.hinemos.webclient.exception.HinemosWebInvalidRequestParameterException;
import com.necsoft.hinemos.webclient.exception.HinemosWebRemoteException;
import com.necsoft.hinemos.webclient.jobmanagement.business.GetJobDetailBusiness;
import com.necsoft.hinemos.webclient.jobmanagement.form.JobDetailForm;
import com.necsoft.hinemos.webclient.json.CommonJson;
import com.necsoft.hinemos.webclient.servlet.CommonServlet;
import com.necsoft.hinemos.webclient.util.ExceptionHandlerUtils;
import com.necsoft.hinemos.webclient.util.LogUtils;
import com.necsoft.hinemos.webclient.util.LoginManager;
import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;

/**
 * This class used for get Job Detail info
 *
 * @version 1.0.0
 * @since 1.0.0
 **/
public class GetJobDetailServlet extends CommonServlet {
    private static final long serialVersionUID = -7775038566425028930L;

    private static LogUtils logUtils = LogUtils
            .getLogUtils(GetJobDetailServlet.class);

    /**
     * Get Job Detail info
     *
     * @param request
     *            : HttpServletRequest
     * @param response
     *            : HttpServletResponse
     * @throws ServletException
     * @throws IOException
     * @throws HinemosWebAccessException
     */
    @Override
    public CommonJson process(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException, HinemosWebAccessException {

        // 中間変数を宣言
        CommonJson result = new CommonJson();

        try {
            // Get Data
            ArrayList<ArrayList<Object>> list = doLoadListInfoData(request);

            // Convert data to JSON structure
            result = DataProcess.doConvertTableContentToJson(list);

        } catch (HinemosWebAccessException ex) {
            logUtils.info(ex.getMessage());
            throw new HinemosWebAccessException();
        } catch (HinemosWebRemoteException ex) {
            logUtils.error(ex.getMessage(), ex.getCause());
            result = ExceptionHandlerUtils.doBuildCommonJson(
                    ExceptionHandlerUtils.LEVEL_WARNING, ex.getMessage(), request.getLocale());

        } catch (Exception ex) {
            logUtils.error(ex.getMessage(), ex.getCause());
            result = ExceptionHandlerUtils.doBuildCommonJson(
                    ExceptionHandlerUtils.LEVEL_ERROR, ex.getMessage(), request.getLocale());
        }
        return result;
    }

    /**
     * ジョブ[ジョブ詳細]情報一覧データを取得
     */
    private ArrayList<ArrayList<Object>> doLoadListInfoData(HttpServletRequest request)
        throws HinemosWebException {

        JobDetailForm form = new JobDetailForm();
        ArrayList<ArrayList<Object>> result = null;

        PopulateBeanUtils.populateBean(form, request);

        // Check parameters of request
        if (!isValidRequestParam(form)) {
            throw new HinemosWebInvalidRequestParameterException();
        }

        //Get loginManager session
        HttpSession session = request.getSession(true);
        synchronized(session) {
            @SuppressWarnings("unchecked")
            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);

            GetJobDetailBusiness business = new GetJobDetailBusiness();
            String managerIp = form.getManagerIpForSearch();
            // シングルログインの場合
            if (managerIp == null || managerIp.trim().isEmpty()) {
                Iterator<LoginManager> iterator = loginManagerMap.values().iterator();
                while (iterator.hasNext()) {
                    LoginManager loginManager = iterator.next();
                    result = business.getJobDetail(form,
                            loginManager.endpointManager);
                    break;
                }
            } else {
                result = business.getJobDetail(form, loginManagerMap.get(managerIp).endpointManager);
            }
        }

        return result;
    }

    /**
     * Check valid parameter
     *
     * @param form
     *            : JobDetailForm
     * @return boolean
     */
    private boolean isValidRequestParam(JobDetailForm form) {
        boolean isValid = true;
        String sessionId = form.getSessionId();

        // Check request sessionId (manager)
        // http リクエストからユーザID判定する
        if (sessionId == null || sessionId.equals("")) {
            isValid = false;
            logUtils.error("sessionId is invalid", sessionId);
        }

        return isValid;
    }
}