/*

Copyright (C) NEC Corporation 2012. All Rights Reserved.
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

*/

package com.necsoft.hinemos.webclient.monitor.servlet;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Locale;
import java.util.Map;
import java.util.Set;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
import com.necsoft.hinemos.webclient.bean.TableColumnInfoJs;
import com.necsoft.hinemos.webclient.common.Constants;
import com.necsoft.hinemos.webclient.common.CssClass;
import com.necsoft.hinemos.webclient.common.DataProcess;
import com.necsoft.hinemos.webclient.common.JsConstant;
import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
import com.necsoft.hinemos.webclient.exception.HinemosWebException;
import com.necsoft.hinemos.webclient.json.CommonJson;
import com.necsoft.hinemos.webclient.json.GridHeaderJson;
import com.necsoft.hinemos.webclient.monitor.action.GetEventListTableDefine;
import com.necsoft.hinemos.webclient.monitor.business.GetEventListTableDefineBusiness;
import com.necsoft.hinemos.webclient.servlet.CommonServlet;
import com.necsoft.hinemos.webclient.util.ExceptionHandlerUtils;
import com.necsoft.hinemos.webclient.util.LogUtils;
import com.necsoft.hinemos.webclient.util.LoginManager;

/**
 * GetEventListTableDefineServlet
 *
 * @version 1.0.0
 * @since 1.0.0
 **/
public class GetEventListTableDefineServlet extends CommonServlet {
    private static final long serialVersionUID = -3895758389407649269L;

    private static LogUtils logUtils = LogUtils
            .getLogUtils(GetEventListTableDefineServlet.class);

    @Override
    public CommonJson process(HttpServletRequest request,
            HttpServletResponse response) throws ServletException, IOException, HinemosWebAccessException {

        CommonJson result = new CommonJson();

        try {
            HttpSession session = request.getSession();
            @SuppressWarnings("unchecked")
            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
            Set<String> managerIpSet = loginManagerMap.keySet();
            ArrayList<TableColumnInfoJs> tblDefine = getEventListTableDefine(request, managerIpSet.size() > 1);
            setModelProperties(tblDefine);
            int eventMaxRow = (Integer)request.getSession().getServletContext().getAttribute(Constants.MONITOR_EVENT_MAX_ROW);
            result = doConvertToJson(tblDefine, request.getLocale(),
                    eventMaxRow,
                    GetEventListTableDefine.SORT_COLUMN_INDEX,
                    GetEventListTableDefine.SORT_ORDER);
        } catch (Exception ex) {
            logUtils.error(ex.getMessage(), ex.getCause());
            result = ExceptionHandlerUtils.doBuildCommonJson(
                    ExceptionHandlerUtils.LEVEL_ERROR, ex.getMessage(), request.getLocale());
        }
        return result;
    }

    /**
     * @param request
     * @return
     * @throws HinemosWebException
     */
    private ArrayList<TableColumnInfoJs> getEventListTableDefine(
            HttpServletRequest request, boolean isManagerIpRequired) throws HinemosWebException {
        GetEventListTableDefineBusiness business = new GetEventListTableDefineBusiness();
        ArrayList<TableColumnInfoJs> tblDefine = business
                .getEventListTableDefine(request.getLocale(), isManagerIpRequired);
        return tblDefine;
    }

    /**
     * @param tblDefine
     */
    private void setModelProperties(ArrayList<TableColumnInfoJs> tblDefine) {
        // Set priority class
        TableColumnInfoJs priority = tblDefine.get(GetEventListTableDefine.PRIORITY);
        priority.setClasses(CssClass.PRIORITY_CELL);
        priority.setFormatter(JsConstant.GRID_FMATTER_PRIORITY);

        TableColumnInfoJs scope = tblDefine.get(GetEventListTableDefine.SCOPE);
        scope.setFormatter(JsConstant.GRID_FMATTER_SCOPE_TYPE);
        Map<String, Object> scopeFmtOpt = new HashMap<String, Object>();
        scopeFmtOpt.put(JsConstant.GRID_FMATTER_SCOPE_TYPE_POSITION,
                GetEventListTableDefine.FACILITY_ID);
        scopeFmtOpt.put(JsConstant.GRID_FMATTER_SCOPE_TYPE_RESERVED, true);
        scope.setFormatoptions(scopeFmtOpt);

        TableColumnInfoJs receiveTime = tblDefine
                .get(GetEventListTableDefine.RECEIVE_TIME);
        receiveTime.setFormatter(JsConstant.GRID_FMATTER_DATE_TIME_PRECISE);
        receiveTime.setClasses(CssClass.GRID_MARKER_CELL_DATE_TIME_PRECISE);

        TableColumnInfoJs outputDate = tblDefine
                .get(GetEventListTableDefine.OUTPUT_DATE);
        outputDate.setFormatter(JsConstant.GRID_FMATTER_DATE_TIME_PRECISE);
        outputDate.setClasses(CssClass.GRID_MARKER_CELL_DATE_TIME_PRECISE);

        tblDefine.get(GetEventListTableDefine.CONFIRMED).setFormatter(
                JsConstant.GRID_FMATTER_CONFIRM_TYPE);
    }

    /**
     * @param tblDefine
     * @param locale
     * @return
     */
    private GridHeaderJson doConvertToJson(ArrayList<TableColumnInfoJs> tblDefine,
            Locale locale, int row_num, int column_index, int sort_order) {
        return DataProcess.doConvertTableDefineToJson(tblDefine, true, locale, row_num, column_index, sort_order);
    }
}
