/*

Copyright (C) NEC Corporation 2012. All Rights Reserved.
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

*/

package com.necsoft.hinemos.webclient.repository.servlet;

import java.io.IOException;
import java.util.ArrayList;
import java.util.LinkedHashMap;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
import com.necsoft.hinemos.webclient.common.DataProcess;
import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
import com.necsoft.hinemos.webclient.exception.HinemosWebException;
import com.necsoft.hinemos.webclient.exception.HinemosWebInvalidRequestParameterException;
import com.necsoft.hinemos.webclient.exception.HinemosWebRemoteException;
import com.necsoft.hinemos.webclient.json.CommonJson;
import com.necsoft.hinemos.webclient.repository.business.GetNodeScopeBusiness;
import com.necsoft.hinemos.webclient.repository.form.NodeScopeForm;
import com.necsoft.hinemos.webclient.servlet.CommonServlet;
import com.necsoft.hinemos.webclient.util.ExceptionHandlerUtils;
import com.necsoft.hinemos.webclient.util.LogUtils;
import com.necsoft.hinemos.webclient.util.LoginManager;
import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;

/**
 * This class used for display data of NodeScope view
 *
 * @version 1.0.0
 * @since 1.0.0
 **/
public class GetNodeScopeServlet extends CommonServlet {

    private static final long serialVersionUID = -7775038566425028930L;

    private static LogUtils logUtils = LogUtils
            .getLogUtils(GetNodeScopeServlet.class);

    @Override
    public CommonJson process(HttpServletRequest request,
            HttpServletResponse response) throws ServletException, IOException,
            HinemosWebAccessException {

        // 中間変数を宣言
        CommonJson result = new CommonJson();
        try {
            //get data
            ArrayList<ArrayList<Object>> listInfoData = getNodeScope(request);

            //convert to json
            result = DataProcess.doConvertTableContentToJson(listInfoData);
        } catch (HinemosWebAccessException ex) {
            logUtils.info(ex.getMessage());
            throw new HinemosWebAccessException();
        } catch (HinemosWebRemoteException ex) {
            logUtils.error(ex.getMessage(), ex.getCause());
            result = ExceptionHandlerUtils.doBuildCommonJson(
                    ExceptionHandlerUtils.LEVEL_WARNING, ex.getMessage(),
                    request.getLocale());

        } catch (Exception ex) {
            logUtils.error(ex.getMessage(), ex.getCause());
            result = ExceptionHandlerUtils.doBuildCommonJson(
                    ExceptionHandlerUtils.LEVEL_ERROR, ex.getMessage(),
                    request.getLocale());
        }
        return result;
    }

    private ArrayList<ArrayList<Object>> getNodeScope(HttpServletRequest request
            ) throws IOException,
            HinemosWebException {
        // 中間変数を宣言
        NodeScopeForm form = new NodeScopeForm();
        PopulateBeanUtils.populateBean(form, request);
        ArrayList<ArrayList<Object>> result = null;

        if (!isValidRequestParam(form)) {
            //対象の設定情報が不正です
            throw new HinemosWebInvalidRequestParameterException("exception.data.param");
        }
        //get loginManager session
        HttpSession session = request.getSession(true);
        synchronized(session) {
            @SuppressWarnings("unchecked")
            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
            GetNodeScopeBusiness business = new GetNodeScopeBusiness();
            result = business.getNodeScope(form, loginManagerMap);
        }

        return result;
    }

    private boolean isValidRequestParam(NodeScopeForm form) {
        boolean isValid = true;
        String facilityId = form.getFacilityId();

        // Check request facilityId (manager)
        // http リクエストからユーザID判定する
        if (facilityId == null || facilityId.equals("")) {
            isValid = false;
            logUtils.error("facilityId is invalid", facilityId);
        }

        return isValid;
    }
}